##  Frequently Asked Questions
For comprehensive information about SAP's AI technology, including detailed technical specifications, data handling policies, and security measures, see [Responsible AI![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Fproducts%2Fartificial-intelligence%2Fai-ethics.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/products/artificial-intelligence/ai-ethics.html").
Are there API endpoints available to the SAP LeanIX AI capabilities?
No. The SAP LeanIX AI capabilities cannot be accessed via any API endpoints.
Is any of my workspace data used to train or fine-tune large language models (LLMs)
No. Workspace data from SAP LeanIX is only used as context for generating AI responses and is not used to train or fine‑tune LLMs. For SAP-wide information on AI ethics, data handling, privacy, and security, see [Responsible AI![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Fproducts%2Fartificial-intelligence%2Fai-ethics.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/products/artificial-intelligence/ai-ethics.html").
Which workspace data is processed by SAP LeanIX AI capabilities?
The data processed depends on the feature and use case. For example, to generate a fact sheet description, relevant data such as the fact sheet name, existing description, and relations may be used.
Personally identifiable information (PII) such as user names or email addresses is not processed by SAP LeanIX AI capabilities.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
